@@ -3,7 +3,7 @@ Gerbera - https://gerbera.io/
 
     grb_fs.h - this file is part of Gerbera.
 
-    Copyright (C) 2022 Gerbera Contributors
+    Copyright (C) 2022-2025 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -59,6 +59,9 @@ public:
     const fs::path& getPath() { return path; }
 };
 
+std::string rtrimPath(std::string& s, unsigned char sep = '/');
+bool isSubDir(const fs::path& path, const fs::path& parent);
+
 /// \brief Checks if the given file is a regular file (imitate same behaviour as std::filesystem::is_regular_file)
 bool isRegularFile(const fs::path& path, std::error_code& ec) noexcept;
 bool isRegularFile(const fs::directory_entry& dirEnt, std::error_code& ec) noexcept;
